pub fn replay_bundle_last_n(opts: ReplayOptions) -> Result<ReplayAudit, String>Expand description
Replay a selected journal slice into the spec from an incident bundle.
pub fn replay_bundle_last_n(opts: ReplayOptions) -> Result<ReplayAudit, String>Replay a selected journal slice into the spec from an incident bundle.